@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -77,8 +77,8 @@ class DatabaseCache {
   inline const class CorrespondenceGraph& CorrespondenceGraph() const;
 
   // Manually add data to cache.
-  void AddCamera(const class Camera& camera);
-  void AddImage(const class Image& image);
+  void AddCamera(class Camera camera);
+  void AddImage(class Image image);
 
   // Load cameras, images, features, and matches from database.
   //
