@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -151,29 +151,22 @@ void Reconstruction::TearDown() {
   }
 }
 
-void Reconstruction::AddCamera(const class Camera& camera) {
-  CHECK(!ExistsCamera(camera.CameraId()));
+void Reconstruction::AddCamera(class Camera camera) {
+  const camera_t camera_id = camera.CameraId();
   CHECK(camera.VerifyParams());
-  cameras_.emplace(camera.CameraId(), camera);
+  CHECK(cameras_.emplace(camera_id, std::move(camera)).second);
 }
 
-void Reconstruction::AddImage(const class Image& image) {
-  CHECK(!ExistsImage(image.ImageId()));
-  images_[image.ImageId()] = image;
+void Reconstruction::AddImage(class Image image) {
+  const image_t image_id = image.ImageId();
+  CHECK(images_.emplace(image_id, std::move(image)).second);
 }
 
-point3D_t Reconstruction::AddPoint3D(const Eigen::Vector3d& xyz,
-                                     const Track& track,
+point3D_t Reconstruction::AddPoint3D(const Eigen::Vector3d& xyz, Track track,
                                      const Eigen::Vector3ub& color) {
   const point3D_t point3D_id = ++num_added_points3D_;
   CHECK(!ExistsPoint3D(point3D_id));
 
-  class Point3D& point3D = points3D_[point3D_id];
-
-  point3D.SetXYZ(xyz);
-  point3D.SetTrack(track);
-  point3D.SetColor(color);
-
   for (const auto& track_el : track.Elements()) {
     class Image& image = Image(track_el.image_id);
     CHECK(!image.Point2D(track_el.point2D_idx).HasPoint3D());
@@ -188,6 +181,11 @@ point3D_t Reconstruction::AddPoint3D(const Eigen::Vector3d& xyz,
                                  kIsContinuedPoint3D);
   }
 
+  class Point3D& point3D = points3D_[point3D_id];
+  point3D.SetXYZ(xyz);
+  point3D.SetTrack(std::move(track));
+  point3D.SetColor(color);
+
   return point3D_id;
 }
 
@@ -1405,7 +1403,7 @@ void Reconstruction::CreateImageDirs(const std::string& path) const {
     }
   }
   for (const auto& dir : image_dirs) {
-    CreateDirIfNotExists(dir);
+    CreateDirIfNotExists(dir, /*recursive=*/true);
   }
 }
 
