@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,7 @@
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
 //
-// Author: Johannes L. Schoenberger (jsch at inf.ethz.ch)
+// Author: Johannes L. Schoenberger (jsch-at-demuc-dot-de)
 
 #ifndef COLMAP_SRC_BASE_TRACK_H_
 #define COLMAP_SRC_BASE_TRACK_H_
@@ -58,7 +58,8 @@ class Track {
 
   // Access all elements.
   inline const std::vector<TrackElement>& Elements() const;
-  inline void SetElements(const std::vector<TrackElement>& elements);
+  inline std::vector<TrackElement>& Elements();
+  inline void SetElements(std::vector<TrackElement> elements);
 
   // Access specific elements.
   inline const TrackElement& Element(const size_t idx) const;
@@ -89,14 +90,14 @@ class Track {
 // Implementation
 ////////////////////////////////////////////////////////////////////////////////
 
-// The number of track elements.
 size_t Track::Length() const { return elements_.size(); }
 
-// Access all elements.
 const std::vector<TrackElement>& Track::Elements() const { return elements_; }
 
-void Track::SetElements(const std::vector<TrackElement>& elements) {
-  elements_ = elements;
+std::vector<TrackElement>& Track::Elements() { return elements_; }
+
+void Track::SetElements(std::vector<TrackElement> elements) {
+  elements_ = std::move(elements);
 }
 
 // Access specific elements.
