@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,7 @@
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
 //
-// Author: Johannes L. Schoenberger (jsch at inf.ethz.ch)
+// Author: Johannes L. Schoenberger (jsch-at-demuc-dot-de)
 
 #include "estimators/triangulation.h"
 
@@ -117,17 +117,14 @@ void TriangulationEstimator::Residuals(const std::vector<X_t>& point_data,
   residuals->resize(point_data.size());
 
   for (size_t i = 0; i < point_data.size(); ++i) {
-    if (HasPointPositiveDepth(pose_data[i].proj_matrix, xyz)) {
-      if (residual_type_ == ResidualType::REPROJECTION_ERROR) {
-        (*residuals)[i] = CalculateReprojectionError(point_data[i].point, xyz,
-                                                     pose_data[i].proj_matrix,
-                                                     *pose_data[i].camera);
-      } else if (residual_type_ == ResidualType::ANGULAR_ERROR) {
-        (*residuals)[i] = CalculateAngularError(point_data[i].point_normalized,
-                                                xyz, pose_data[i].proj_matrix);
-      }
-    } else {
-      (*residuals)[i] = std::numeric_limits<double>::max();
+    if (residual_type_ == ResidualType::REPROJECTION_ERROR) {
+      (*residuals)[i] = CalculateSquaredReprojectionError(
+          point_data[i].point, xyz, pose_data[i].proj_matrix,
+          *pose_data[i].camera);
+    } else if (residual_type_ == ResidualType::ANGULAR_ERROR) {
+      const double angular_error = CalculateNormalizedAngularError(
+          point_data[i].point_normalized, xyz, pose_data[i].proj_matrix);
+      (*residuals)[i] = angular_error * angular_error;
     }
   }
 }
