@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,7 @@
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
 //
-// Author: Johannes L. Schoenberger (jsch at inf.ethz.ch)
+// Author: Johannes L. Schoenberger (jsch-at-demuc-dot-de)
 
 #ifndef COLMAP_SRC_ESTIMATORS_TWO_VIEW_GEOMETRY_H_
 #define COLMAP_SRC_ESTIMATORS_TWO_VIEW_GEOMETRY_H_
@@ -104,6 +104,13 @@ struct TwoViewGeometry {
     // Whether to ignore watermark models in multiple model estimation.
     bool multiple_ignore_watermark = true;
 
+    // In case the user asks for it, only going to estimate a Homography
+    // between both cameras.
+    bool force_H_use = false;
+
+    // Whether to compute the relative pose between the two views.
+    bool compute_relative_pose = false;
+
     // Options used to robustly estimate the geometry.
     RANSACOptions ransac_options;
 
@@ -214,6 +221,22 @@ struct TwoViewGeometry {
                             const FeatureMatches& matches,
                             const Options& options);
 
+  // Estimate two-view geometry using a Homography,
+  // depending on the option was user specified or not.
+  //
+  // @param camera1         Camera of first image.
+  // @param points1         Feature points in first image.
+  // @param camera2         Camera of second image.
+  // @param points2         Feature points in second image.
+  // @param matches         Feature matches between first and second image.
+  // @param options         Two-view geometry estimation options.
+  void EstimateHomography(const Camera& camera1,
+                          const std::vector<Eigen::Vector2d>& points1,
+                          const Camera& camera2,
+                          const std::vector<Eigen::Vector2d>& points2,
+                          const FeatureMatches& matches,
+                          const Options& options);
+
   // Detect if inlier matches are caused by a watermark.
   // A watermark causes a pure translation in the border are of the image.
   static bool DetectWatermark(const Camera& camera1,
