@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -259,7 +259,7 @@ bool BundleAdjuster::Solve(Reconstruction* reconstruction) {
   CHECK_NOTNULL(reconstruction);
   CHECK(!problem_) << "Cannot use the same BundleAdjuster multiple times";
 
-  problem_.reset(new ceres::Problem());
+  problem_ = std::make_unique<ceres::Problem>();
 
   ceres::LossFunction* loss_function = options_.CreateLossFunction();
   SetUp(reconstruction, loss_function);
@@ -416,15 +416,11 @@ void BundleAdjuster::AddImageToProblem(const image_t image_id,
 
     // Set pose parameterization.
     if (!constant_pose) {
-      ceres::LocalParameterization* quaternion_parameterization =
-          new ceres::QuaternionParameterization;
-      problem_->SetParameterization(qvec_data, quaternion_parameterization);
+      SetQuaternionManifold(problem_.get(), qvec_data);
       if (config_.HasConstantTvec(image_id)) {
         const std::vector<int>& constant_tvec_idxs =
             config_.ConstantTvec(image_id);
-        ceres::SubsetParameterization* tvec_parameterization =
-            new ceres::SubsetParameterization(3, constant_tvec_idxs);
-        problem_->SetParameterization(tvec_data, tvec_parameterization);
+        SetSubsetManifold(3, constant_tvec_idxs, problem_.get(), tvec_data);
       }
     }
   }
@@ -511,11 +507,9 @@ void BundleAdjuster::ParameterizeCameras(Reconstruction* reconstruction) {
       }
 
       if (const_camera_params.size() > 0) {
-        ceres::SubsetParameterization* camera_params_parameterization =
-            new ceres::SubsetParameterization(
-                static_cast<int>(camera.NumParams()), const_camera_params);
-        problem_->SetParameterization(camera.ParamsData(),
-                                      camera_params_parameterization);
+        SetSubsetManifold(static_cast<int>(camera.NumParams()),
+                          const_camera_params, problem_.get(),
+                          camera.ParamsData());
       }
     }
   }
@@ -822,7 +816,7 @@ bool RigBundleAdjuster::Solve(Reconstruction* reconstruction,
     }
   }
 
-  problem_.reset(new ceres::Problem());
+  problem_ = std::make_unique<ceres::Problem>();
 
   ceres::LossFunction* loss_function = options_.CreateLossFunction();
   SetUp(reconstruction, camera_rigs, loss_function);
@@ -1058,9 +1052,7 @@ void RigBundleAdjuster::AddImageToProblem(const image_t image_id,
     if (!constant_pose && constant_tvec) {
       const std::vector<int>& constant_tvec_idxs =
           config_.ConstantTvec(image_id);
-      ceres::SubsetParameterization* tvec_parameterization =
-          new ceres::SubsetParameterization(3, constant_tvec_idxs);
-      problem_->SetParameterization(tvec_data, tvec_parameterization);
+      SetSubsetManifold(3, constant_tvec_idxs, problem_.get(), tvec_data);
     }
   }
 }
@@ -1143,9 +1135,7 @@ void RigBundleAdjuster::ComputeCameraRigPoses(
 
 void RigBundleAdjuster::ParameterizeCameraRigs(Reconstruction* reconstruction) {
   for (double* qvec_data : parameterized_qvec_data_) {
-    ceres::LocalParameterization* quaternion_parameterization =
-        new ceres::QuaternionParameterization;
-    problem_->SetParameterization(qvec_data, quaternion_parameterization);
+    SetQuaternionManifold(problem_.get(), qvec_data);
   }
 }
 
