@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -35,7 +35,7 @@
 #include <Eigen/Core>
 #include <boost/heap/fibonacci_heap.hpp>
 
-#include "FLANN/flann.hpp"
+#include "flann/flann.hpp"
 #include "feature/types.h"
 #include "retrieval/inverted_file.h"
 #include "retrieval/inverted_index.h"
