@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,7 @@
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
 //
-// Author: Johannes L. Schoenberger (jsch at inf.ethz.ch)
+// Author: Johannes L. Schoenberger (jsch-at-demuc-dot-de)
 
 #define TEST_NAME "retrieval/visual_index"
 #include "util/testing.h"
@@ -104,11 +104,26 @@ void TestVocabTreeType() {
   }
 }
 
-BOOST_AUTO_TEST_CASE(TestVocabTree) {
+BOOST_AUTO_TEST_CASE(TestVocabTree_uint8_t_128_64) {
   TestVocabTreeType<uint8_t, 128, 64>();
+}
+
+BOOST_AUTO_TEST_CASE(TestVocabTree_uint8_t_64_64) {
   TestVocabTreeType<uint8_t, 64, 64>();
+}
+
+BOOST_AUTO_TEST_CASE(TestVocabTree_uint8_t_32_16) {
   TestVocabTreeType<uint8_t, 32, 16>();
+}
+
+BOOST_AUTO_TEST_CASE(TestVocabTree_int_32_16) {
   TestVocabTreeType<int, 32, 16>();
+}
+
+BOOST_AUTO_TEST_CASE(TestVocabTree_float_32_16) {
   TestVocabTreeType<float, 32, 16>();
+}
+
+BOOST_AUTO_TEST_CASE(TestVocabTree_double_32_16) {
   TestVocabTreeType<double, 32, 16>();
 }
