@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,7 @@
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
 //
-// Author: Johannes L. Schoenberger (jsch at inf.ethz.ch)
+// Author: Johannes L. Schoenberger (jsch-at-demuc-dot-de)
 
 #include "ui/automatic_reconstruction_widget.h"
 
@@ -46,6 +46,8 @@ AutomaticReconstructionWidget::AutomaticReconstructionWidget(
   AddSpacer();
   AddOptionDirPath(&options_.image_path, "Image folder");
   AddSpacer();
+  AddOptionDirPath(&options_.mask_path, "Mask folder");
+  AddSpacer();
   AddOptionFilePath(&options_.vocab_tree_path, "Vocabulary tree<br>(optional)");
 
   AddSpacer();
@@ -175,14 +177,12 @@ void AutomaticReconstructionWidget::Run() {
   main_window_->RenderClear();
   main_window_->RenderNow();
 
-  AutomaticReconstructionController* controller =
-      new AutomaticReconstructionController(
-          options_, &main_window_->reconstruction_manager_);
-
+  auto controller = std::make_unique<AutomaticReconstructionController>(
+      options_, &main_window_->reconstruction_manager_);
   controller->AddCallback(Thread::FINISHED_CALLBACK,
                           [this]() { render_result_->trigger(); });
-
-  thread_control_widget_->StartThread("Reconstructing...", true, controller);
+  thread_control_widget_->StartThread("Reconstructing...", true,
+                                      std::move(controller));
 }
 
 void AutomaticReconstructionWidget::RenderResult() {
