@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,7 @@
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
 //
-// Author: Johannes L. Schoenberger (jsch at inf.ethz.ch)
+// Author: Johannes L. Schoenberger (jsch-at-demuc-dot-de)
 
 #ifndef COLMAP_SRC_UI_COLORMAPS_H_
 #define COLMAP_SRC_UI_COLORMAPS_H_
@@ -44,13 +44,14 @@ namespace colmap {
 class PointColormapBase {
  public:
   PointColormapBase();
+  virtual ~PointColormapBase() = default;
 
   virtual void Prepare(EIGEN_STL_UMAP(camera_t, Camera) & cameras,
                        EIGEN_STL_UMAP(image_t, Image) & images,
                        EIGEN_STL_UMAP(point3D_t, Point3D) & points3D,
                        std::vector<image_t>& reg_image_ids) = 0;
 
-  virtual Eigen::Vector3f ComputeColor(const point3D_t point3D_id,
+  virtual Eigen::Vector4f ComputeColor(const point3D_t point3D_id,
                                        const Point3D& point3D) = 0;
 
   void UpdateScale(std::vector<float>* values);
@@ -70,10 +71,10 @@ class PointColormapPhotometric : public PointColormapBase {
   void Prepare(EIGEN_STL_UMAP(camera_t, Camera) & cameras,
                EIGEN_STL_UMAP(image_t, Image) & images,
                EIGEN_STL_UMAP(point3D_t, Point3D) & points3D,
-               std::vector<image_t>& reg_image_ids);
+               std::vector<image_t>& reg_image_ids) override;
 
-  Eigen::Vector3f ComputeColor(const point3D_t point3D_id,
-                               const Point3D& point3D);
+  Eigen::Vector4f ComputeColor(const point3D_t point3D_id,
+                               const Point3D& point3D) override;
 };
 
 // Map color according to error.
@@ -82,10 +83,10 @@ class PointColormapError : public PointColormapBase {
   void Prepare(EIGEN_STL_UMAP(camera_t, Camera) & cameras,
                EIGEN_STL_UMAP(image_t, Image) & images,
                EIGEN_STL_UMAP(point3D_t, Point3D) & points3D,
-               std::vector<image_t>& reg_image_ids);
+               std::vector<image_t>& reg_image_ids) override;
 
-  Eigen::Vector3f ComputeColor(const point3D_t point3D_id,
-                               const Point3D& point3D);
+  Eigen::Vector4f ComputeColor(const point3D_t point3D_id,
+                               const Point3D& point3D) override;
 };
 
 // Map color according to track length.
@@ -94,10 +95,10 @@ class PointColormapTrackLen : public PointColormapBase {
   void Prepare(EIGEN_STL_UMAP(camera_t, Camera) & cameras,
                EIGEN_STL_UMAP(image_t, Image) & images,
                EIGEN_STL_UMAP(point3D_t, Point3D) & points3D,
-               std::vector<image_t>& reg_image_ids);
+               std::vector<image_t>& reg_image_ids) override;
 
-  Eigen::Vector3f ComputeColor(const point3D_t point3D_id,
-                               const Point3D& point3D);
+  Eigen::Vector4f ComputeColor(const point3D_t point3D_id,
+                               const Point3D& point3D) override;
 };
 
 // Map color according to ground-resolution.
@@ -106,15 +107,70 @@ class PointColormapGroundResolution : public PointColormapBase {
   void Prepare(EIGEN_STL_UMAP(camera_t, Camera) & cameras,
                EIGEN_STL_UMAP(image_t, Image) & images,
                EIGEN_STL_UMAP(point3D_t, Point3D) & points3D,
-               std::vector<image_t>& reg_image_ids);
+               std::vector<image_t>& reg_image_ids) override;
 
-  Eigen::Vector3f ComputeColor(const point3D_t point3D_id,
-                               const Point3D& point3D);
+  Eigen::Vector4f ComputeColor(const point3D_t point3D_id,
+                               const Point3D& point3D) override;
 
  private:
   std::unordered_map<point3D_t, float> resolutions_;
 };
 
+// Base class for image color mapping.
+class ImageColormapBase {
+ public:
+  ImageColormapBase();
+  virtual ~ImageColormapBase() = default;
+
+  virtual void Prepare(EIGEN_STL_UMAP(camera_t, Camera) & cameras,
+                       EIGEN_STL_UMAP(image_t, Image) & images,
+                       EIGEN_STL_UMAP(point3D_t, Point3D) & points3D,
+                       std::vector<image_t>& reg_image_ids) = 0;
+
+  virtual void ComputeColor(const Image& image, Eigen::Vector4f* plane_color,
+                            Eigen::Vector4f* frame_color) = 0;
+
+  const static Eigen::Vector4f kDefaultPlaneColor;
+  const static Eigen::Vector4f kDefaultFrameColor;
+};
+
+// Use uniform color for all images.
+class ImageColormapUniform : public ImageColormapBase {
+ public:
+  void Prepare(EIGEN_STL_UMAP(camera_t, Camera) & cameras,
+               EIGEN_STL_UMAP(image_t, Image) & images,
+               EIGEN_STL_UMAP(point3D_t, Point3D) & points3D,
+               std::vector<image_t>& reg_image_ids) override;
+
+  void ComputeColor(const Image& image, Eigen::Vector4f* plane_color,
+                    Eigen::Vector4f* frame_color) override;
+
+  Eigen::Vector4f uniform_plane_color = kDefaultPlaneColor;
+  Eigen::Vector4f uniform_frame_color = kDefaultFrameColor;
+};
+
+// Use color for images with specific words in their name.
+class ImageColormapNameFilter : public ImageColormapBase {
+ public:
+  void Prepare(EIGEN_STL_UMAP(camera_t, Camera) & cameras,
+               EIGEN_STL_UMAP(image_t, Image) & images,
+               EIGEN_STL_UMAP(point3D_t, Point3D) & points3D,
+               std::vector<image_t>& reg_image_ids) override;
+
+  void AddColorForWord(const std::string& word,
+                       const Eigen::Vector4f& plane_color,
+                       const Eigen::Vector4f& frame_color);
+
+  void ComputeColor(const Image& image, Eigen::Vector4f* plane_color,
+                    Eigen::Vector4f* frame_color) override;
+
+ private:
+  // The plane and frame colors for different words.
+  std::vector<
+      std::pair<std::string, std::pair<Eigen::Vector4f, Eigen::Vector4f>>>
+      image_name_colors_;
+};
+
 }  // namespace colmap
 
 #endif  // COLMAP_SRC_UI_COLORMAPS_H_
