@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,10 +27,12 @@
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
 //
-// Author: Johannes L. Schoenberger (jsch at inf.ethz.ch)
+// Author: Johannes L. Schoenberger (jsch-at-demuc-dot-de)
 
 #include "ui/render_options_widget.h"
 
+#include "ui/colormaps.h"
+
 namespace colmap {
 
 RenderOptionsWidget::RenderOptionsWidget(QWidget* parent,
@@ -41,20 +43,16 @@ RenderOptionsWidget::RenderOptionsWidget(QWidget* parent,
       automatic_update(true),
       options_(options),
       model_viewer_widget_(model_viewer_widget),
+      background_color_(1.0f, 1.0f, 1.0f, 1.0f),
       point3D_colormap_scale_(1),
       point3D_colormap_min_q_(0.02),
-      point3D_colormap_max_q_(0.98) {
-  bg_color_[0] = 1.0;
-  bg_color_[1] = 1.0;
-  bg_color_[2] = 1.0;
-
+      point3D_colormap_max_q_(0.98),
+      image_plane_color_(ImageColormapUniform::kDefaultPlaneColor),
+      image_frame_color_(ImageColormapUniform::kDefaultFrameColor) {
   setWindowFlags(Qt::Widget | Qt::WindowStaysOnTopHint | Qt::Tool);
   setWindowModality(Qt::NonModal);
   setWindowTitle("Render options");
 
-  QLabel* point_size_label = new QLabel(tr("Point size"), this);
-  point_size_label->setFont(font());
-  point_size_label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
   QHBoxLayout* point_size_layout = new QHBoxLayout();
   QPushButton* decrease_point_size = new QPushButton("-", this);
   connect(decrease_point_size, &QPushButton::released, this,
@@ -64,12 +62,8 @@ RenderOptionsWidget::RenderOptionsWidget(QWidget* parent,
           &RenderOptionsWidget::IncreasePointSize);
   point_size_layout->addWidget(decrease_point_size);
   point_size_layout->addWidget(increase_point_size);
-  grid_layout_->addWidget(point_size_label, grid_layout_->rowCount(), 0);
-  grid_layout_->addLayout(point_size_layout, grid_layout_->rowCount() - 1, 1);
+  AddLayoutRow("Point size", point_size_layout);
 
-  QLabel* camera_size_label = new QLabel(tr("Camera size"), this);
-  camera_size_label->setFont(font());
-  camera_size_label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
   QHBoxLayout* camera_size_layout = new QHBoxLayout();
   QPushButton* decrease_camera_size = new QPushButton("-", this);
   connect(decrease_camera_size, &QPushButton::released, this,
@@ -79,25 +73,29 @@ RenderOptionsWidget::RenderOptionsWidget(QWidget* parent,
           &RenderOptionsWidget::IncreaseCameraSize);
   camera_size_layout->addWidget(decrease_camera_size);
   camera_size_layout->addWidget(increase_camera_size);
-  grid_layout_->addWidget(camera_size_label, grid_layout_->rowCount(), 0);
-  grid_layout_->addLayout(camera_size_layout, grid_layout_->rowCount() - 1, 1);
+  AddLayoutRow("Camera size", camera_size_layout);
 
   AddSpacer();
 
   projection_cb_ = new QComboBox(this);
   projection_cb_->addItem("Perspective");
   projection_cb_->addItem("Orthographic");
-
-  QLabel* projection_label = new QLabel(tr("Projection"), this);
-  projection_label->setFont(font());
-  projection_label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-  grid_layout_->addWidget(projection_label, grid_layout_->rowCount(), 0);
-  grid_layout_->addWidget(projection_cb_, grid_layout_->rowCount() - 1, 1);
+  AddWidgetRow("Projection", projection_cb_);
 
   AddSpacer();
 
-  AddOptionDouble(&options->render->max_error, "Max. error [px]");
-  AddOptionInt(&options->render->min_track_len, "Min. track length", 0);
+  QPushButton* select_background_color =
+      new QPushButton(tr("Select color"), this);
+  grid_layout_->addWidget(select_background_color, grid_layout_->rowCount() - 1,
+                          1);
+  connect(select_background_color, &QPushButton::released, this,
+          [&]() { SelectColor("Background color", &background_color_); });
+  AddWidgetRow("Background", select_background_color);
+
+  AddSpacer();
+
+  AddOptionDouble(&options->render->max_error, "Point max. error [px]");
+  AddOptionInt(&options->render->min_track_len, "Point min. track length", 0);
 
   AddSpacer();
 
@@ -106,13 +104,7 @@ RenderOptionsWidget::RenderOptionsWidget(QWidget* parent,
   point3D_colormap_cb_->addItem("Error");
   point3D_colormap_cb_->addItem("Track-Length");
   point3D_colormap_cb_->addItem("Ground-Resolution");
-
-  QLabel* colormap_label = new QLabel(tr("Point colormap"), this);
-  colormap_label->setFont(font());
-  colormap_label->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-  grid_layout_->addWidget(colormap_label, grid_layout_->rowCount(), 0);
-  grid_layout_->addWidget(point3D_colormap_cb_, grid_layout_->rowCount() - 1,
-                          1);
+  AddWidgetRow("Point colormap", point3D_colormap_cb_);
 
   AddOptionDouble(&point3D_colormap_min_q_, "Point colormap minq", 0, 1, 0.001,
                   3);
@@ -120,19 +112,46 @@ RenderOptionsWidget::RenderOptionsWidget(QWidget* parent,
                   3);
   AddOptionDouble(&point3D_colormap_scale_, "Point colormap scale", -1e7, 1e7);
 
+  // Show the above items only for other colormaps than the photometric one.
+  HideOption(&point3D_colormap_min_q_);
+  HideOption(&point3D_colormap_max_q_);
+  HideOption(&point3D_colormap_scale_);
+  connect(point3D_colormap_cb_,
+          (void (QComboBox::*)(int)) & QComboBox::currentIndexChanged, this,
+          &RenderOptionsWidget::SelectPointColormap);
+
   AddSpacer();
 
-  bg_red_spinbox_ =
-      AddOptionDouble(&bg_color_[0], "Background red", 0.0, 1.0, 0.001, 3);
-  bg_green_spinbox_ =
-      AddOptionDouble(&bg_color_[1], "Background green", 0.0, 1.0, 0.001, 3);
-  bg_blue_spinbox_ =
-      AddOptionDouble(&bg_color_[2], "Background blue", 0.0, 1.0, 0.001, 3);
+  image_colormap_cb_ = new QComboBox(this);
+  image_colormap_cb_->addItem("Uniform color");
+  image_colormap_cb_->addItem("Images with words in name");
+  AddWidgetRow("Image colormap", image_colormap_cb_);
 
-  QPushButton* select_color = new QPushButton(tr("Select color"), this);
-  grid_layout_->addWidget(select_color, grid_layout_->rowCount(), 1);
-  connect(select_color, &QPushButton::released, this,
-          &RenderOptionsWidget::SelectBackgroundColor);
+  select_image_plane_color_ = new QPushButton(tr("Select color"), this);
+  connect(select_image_plane_color_, &QPushButton::released, this,
+          [&]() { SelectColor("Image plane color", &image_plane_color_); });
+  AddWidgetRow("Image plane", select_image_plane_color_);
+
+  select_image_frame_color_ = new QPushButton(tr("Select color"), this);
+  connect(select_image_frame_color_, &QPushButton::released, this,
+          [&]() { SelectColor("Image frame color", &image_frame_color_); });
+  AddWidgetRow("Image frame", select_image_frame_color_);
+
+  image_colormap_name_filter_layout_ = new QHBoxLayout();
+  QPushButton* image_colormap_add_word = new QPushButton("Add", this);
+  connect(image_colormap_add_word, &QPushButton::released, this,
+          &RenderOptionsWidget::ImageColormapNameFilterAddWord);
+  QPushButton* image_colormap_clear_words = new QPushButton("Clear", this);
+  connect(image_colormap_clear_words, &QPushButton::released, this,
+          &RenderOptionsWidget::ImageColormapNameFilterClearWords);
+  image_colormap_name_filter_layout_->addWidget(image_colormap_add_word);
+  image_colormap_name_filter_layout_->addWidget(image_colormap_clear_words);
+  AddLayoutRow("Words", image_colormap_name_filter_layout_);
+
+  HideLayout(image_colormap_name_filter_layout_);
+  connect(image_colormap_cb_,
+          (void (QComboBox::*)(int)) & QComboBox::currentIndexChanged, this,
+          &RenderOptionsWidget::SelectImageColormap);
 
   AddSpacer();
 
@@ -160,7 +179,8 @@ void RenderOptionsWidget::Apply() {
   counter = 0;
 
   ApplyProjection();
-  ApplyColormap();
+  ApplyPointColormap();
+  ApplyImageColormap();
   ApplyBackgroundColor();
 
   model_viewer_widget_->ReloadReconstruction();
@@ -183,7 +203,7 @@ void RenderOptionsWidget::ApplyProjection() {
   }
 }
 
-void RenderOptionsWidget::ApplyColormap() {
+void RenderOptionsWidget::ApplyPointColormap() {
   PointColormapBase* point3D_color_map;
 
   switch (point3D_colormap_cb_->currentIndex()) {
@@ -211,18 +231,69 @@ void RenderOptionsWidget::ApplyColormap() {
   model_viewer_widget_->SetPointColormap(point3D_color_map);
 }
 
-void RenderOptionsWidget::ApplyBackgroundColor() {
-  model_viewer_widget_->SetBackgroundColor(bg_color_[0], bg_color_[1],
-                                           bg_color_[2]);
+void RenderOptionsWidget::ApplyImageColormap() {
+  ImageColormapBase* image_color_map;
+
+  switch (image_colormap_cb_->currentIndex()) {
+    case 0:
+      image_color_map = new ImageColormapUniform();
+      reinterpret_cast<ImageColormapUniform*>(image_color_map)
+          ->uniform_plane_color = image_plane_color_;
+      reinterpret_cast<ImageColormapUniform*>(image_color_map)
+          ->uniform_frame_color = image_frame_color_;
+      break;
+    case 1:
+      image_color_map =
+          new ImageColormapNameFilter(image_colormap_name_filter_);
+      break;
+    default:
+      image_color_map = new ImageColormapUniform();
+      break;
+  }
+
+  model_viewer_widget_->SetImageColormap(image_color_map);
 }
 
-void RenderOptionsWidget::SelectBackgroundColor() {
-  const QColor initial_color(255 * bg_color_[0], 255 * bg_color_[1],
-                             255 * bg_color_[2]);
-  const QColor selected_color = QColorDialog::getColor(initial_color);
-  bg_red_spinbox_->setValue(selected_color.red() / 255.0);
-  bg_green_spinbox_->setValue(selected_color.green() / 255.0);
-  bg_blue_spinbox_->setValue(selected_color.blue() / 255.0);
+void RenderOptionsWidget::ApplyBackgroundColor() {
+  model_viewer_widget_->SetBackgroundColor(
+      background_color_(0), background_color_(1), background_color_(2));
+}
+
+void RenderOptionsWidget::SelectColor(const std::string& title,
+                                      Eigen::Vector4f* color) {
+  const QColor initial_color(
+      static_cast<int>(255 * (*color)(0)), static_cast<int>(255 * (*color)(1)),
+      static_cast<int>(255 * (*color)(2)), static_cast<int>(255 * (*color)(3)));
+  const QColor selected_color =
+      QColorDialog::getColor(initial_color, this, title.c_str());
+  (*color)(0) = selected_color.red() / 255.0;
+  (*color)(1) = selected_color.green() / 255.0;
+  (*color)(2) = selected_color.blue() / 255.0;
+  (*color)(3) = selected_color.alpha() / 255.0;
+}
+
+void RenderOptionsWidget::SelectPointColormap(const int idx) {
+  if (idx == 0) {
+    HideOption(&point3D_colormap_scale_);
+    HideOption(&point3D_colormap_min_q_);
+    HideOption(&point3D_colormap_max_q_);
+  } else {
+    ShowOption(&point3D_colormap_scale_);
+    ShowOption(&point3D_colormap_min_q_);
+    ShowOption(&point3D_colormap_max_q_);
+  }
+}
+
+void RenderOptionsWidget::SelectImageColormap(const int idx) {
+  if (idx == 0) {
+    ShowWidget(select_image_plane_color_);
+    ShowWidget(select_image_frame_color_);
+    HideLayout(image_colormap_name_filter_layout_);
+  } else {
+    HideWidget(select_image_plane_color_);
+    HideWidget(select_image_frame_color_);
+    ShowLayout(image_colormap_name_filter_layout_);
+  }
 }
 
 void RenderOptionsWidget::IncreasePointSize() {
@@ -245,4 +316,26 @@ void RenderOptionsWidget::DecreaseCameraSize() {
   model_viewer_widget_->ChangeCameraSize(kDelta);
 }
 
+void RenderOptionsWidget::ImageColormapNameFilterAddWord() {
+  bool word_ok;
+  const QString word =
+      QInputDialog::getText(this, "", "Word:", QLineEdit::Normal, "", &word_ok);
+  if (!word_ok || word == "") {
+    return;
+  }
+
+  Eigen::Vector4f plane_color(ImageColormapBase::kDefaultPlaneColor);
+  SelectColor("Image plane color", &plane_color);
+
+  Eigen::Vector4f frame_color(ImageColormapBase::kDefaultFrameColor);
+  SelectColor("Image frame color", &frame_color);
+
+  image_colormap_name_filter_.AddColorForWord(word.toUtf8().constData(),
+                                              plane_color, frame_color);
+}
+
+void RenderOptionsWidget::ImageColormapNameFilterClearWords() {
+  image_colormap_name_filter_ = ImageColormapNameFilter();
+}
+
 }  // namespace colmap
