@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,7 @@
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
 //
-// Author: Johannes L. Schoenberger (jsch at inf.ethz.ch)
+// Author: Johannes L. Schoenberger (jsch-at-demuc-dot-de)
 
 #include "ui/undistortion_widget.h"
 
@@ -48,10 +48,7 @@ UndistortionWidget::UndistortionWidget(QWidget* parent,
   output_format_->addItem("PMVS");
   output_format_->addItem("CMP-MVS");
   output_format_->setFont(font());
-
-  AddOptionRow("format", output_format_);
-
-  UndistortCameraOptions default_options;
+  AddWidgetRow("format", output_format_);
 
   AddOptionDouble(&undistortion_options_.min_scale, "min_scale", 0);
   AddOptionDouble(&undistortion_options_.max_scale, "max_scale", 0);
@@ -85,25 +82,27 @@ void UndistortionWidget::Undistort() {
   WriteOptions();
 
   if (IsValid()) {
-    Thread* undistorter = nullptr;
+    std::unique_ptr<Thread> undistorter;
 
     if (output_format_->currentIndex() == 0) {
-      undistorter =
-          new COLMAPUndistorter(undistortion_options_, *reconstruction_,
-                                *options_->image_path, output_path_);
+      undistorter = std::make_unique<COLMAPUndistorter>(
+          undistortion_options_, *reconstruction_, *options_->image_path,
+          output_path_);
     } else if (output_format_->currentIndex() == 1) {
-      undistorter = new PMVSUndistorter(undistortion_options_, *reconstruction_,
-                                        *options_->image_path, output_path_);
+      undistorter = std::make_unique<PMVSUndistorter>(
+          undistortion_options_, *reconstruction_, *options_->image_path,
+          output_path_);
     } else if (output_format_->currentIndex() == 2) {
-      undistorter =
-          new CMPMVSUndistorter(undistortion_options_, *reconstruction_,
-                                *options_->image_path, output_path_);
+      undistorter = std::make_unique<CMPMVSUndistorter>(
+          undistortion_options_, *reconstruction_, *options_->image_path,
+          output_path_);
     } else {
       QMessageBox::critical(this, "", tr("Invalid output format"));
       return;
     }
 
-    thread_control_widget_->StartThread("Undistorting...", true, undistorter);
+    thread_control_widget_->StartThread("Undistorting...", true,
+                                        std::move(undistorter));
   } else {
     QMessageBox::critical(this, "", tr("Invalid output path"));
   }
