@@ -1,4 +1,4 @@
-// Copyright (c) 2018, ETH Zurich and UNC Chapel Hill.
+// Copyright (c) 2023, ETH Zurich and UNC Chapel Hill.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,7 @@
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
 //
-// Author: Johannes L. Schoenberger (jsch at inf.ethz.ch)
+// Author: Johannes L. Schoenberger (jsch-at-demuc-dot-de)
 
 #define TEST_NAME "util/opengl_utils"
 #include "util/testing.h"
@@ -46,15 +46,11 @@ BOOST_AUTO_TEST_CASE(TestOpenGLContextManager) {
   char* argv[] = {app_name};
   QApplication app(argc, argv);
 
-  if (!OpenGLContextManager::HasOpenGL()) {
-    return;
-  }
-
   OpenGLContextManager manager;
 
   std::thread thread([&manager]() {
-    manager.MakeCurrent();
-    manager.MakeCurrent();
+    BOOST_CHECK(manager.MakeCurrent());
+    BOOST_CHECK(manager.MakeCurrent());
     qApp->exit();
   });
 
@@ -68,13 +64,9 @@ BOOST_AUTO_TEST_CASE(TestRunThreadWithOpenGLContext) {
   char* argv[] = {app_name};
   QApplication app(argc, argv);
 
-  if (!OpenGLContextManager::HasOpenGL()) {
-    return;
-  }
-
   class TestThread : public Thread {
    private:
-    void Run() { opengl_context_.MakeCurrent(); }
+    void Run() { BOOST_CHECK(opengl_context_.MakeCurrent()); }
     OpenGLContextManager opengl_context_;
   };
 
